@@ -58,7 +58,7 @@ void
 showHelp(FILE *out, char *progname) 
 {
   fprintf(out,"Usage: %s [-dxohv] [-t] [char-alias...]\n", progname); 
-#define P(s)	puts(s);
+#define P(s)	fputs(s "\n", out);
 #include "splashscreen.h"
 #undef P
 
